@@ -48,16 +48,20 @@ which you can start to make your own simple game-specific engines.
 use 5.008005;
 use strict;
 use warnings;
-use OpenGL 0.64;
-use SDL    2.524;
+use File::Spec                   0.80 ();
+use File::ShareDir               1.02 ();
+use OpenGL                       0.64 ':all';
+use SDL                         2.524 ':all';
 use SDL::Event                        ':all';
 use SDLx::App                         ();
 use SDL::Tutorial::3DWorld::Light     ();
 use SDL::Tutorial::3DWorld::Actor     ();
 use SDL::Tutorial::3DWorld::Camera    ();
+use SDL::Tutorial::3DWorld::Skybox    ();
+use SDL::Tutorial::3DWorld::Texture   ();
 use SDL::Tutorial::3DWorld::Landscape ();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =pod
 
@@ -77,18 +81,18 @@ sub new {
 		height => 600,
 	}, $class;
 
+	# A pretty skybox background for our world
+	$self->{skybox} = SDL::Tutorial::3DWorld::Skybox->new(
+		type      => 'jpg',
+		directory => File::Spec->catdir(
+			File::ShareDir::dist_dir('SDL-Tutorial-3DWorld'),
+			'skybox',
+		),
+	);
+
 	# Create the landscape
 	$self->{landscape} = SDL::Tutorial::3DWorld::Landscape->new;
 
-	# Light the scene with a single overhead light
-	$self->{lights} = [
-		SDL::Tutorial::3DWorld::Light->new(
-			X => 1,
-			Y => 10,
-			Z => 2,
-		),
-	];
-
 	# Place three airborn stationary teapots in the scene
 	$self->{actors} = [
 		SDL::Tutorial::3DWorld::Actor->new(
@@ -108,6 +112,15 @@ sub new {
 		),
 	];
 
+	# Light the world with a single overhead light
+	$self->{lights} = [
+		SDL::Tutorial::3DWorld::Light->new(
+			X => 1,
+			Y => 10,
+			Z => 2,
+		),
+	];
+
 	# Place the camera at a typical eye height a few metres back
 	# from the teapots and facing slightly down towards it.
 	$self->{camera} = SDL::Tutorial::3DWorld::Camera->new(
@@ -178,26 +191,26 @@ sub init {
 	# correct shape culling for us and we don't have to care about it.
 	glEnable( GL_DEPTH_TEST );
 
-	# Try hard to make the perspective not suck
-	glHint( GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST );
-
-	# Enable GLUT support
-	OpenGL::glutInit();
+	# Make shading prettier
+	glShadeModel( GL_SMOOTH );
 
 	# If we have any lights, initialise lighting
 	if ( @{$self->{lights}} ) {
 		glEnable( GL_LIGHTING );
-
-		# Lets just use flat shading for now
-		glShadeModel( GL_SMOOTH );
 	}
 
-	# Initialise the camera so we are looking at something
+	# Initialise the camera so we can look at things
 	$self->{camera}->init( $self->{width}, $self->{height} );
 
+	# Initialise and load the skybox
+	$self->{skybox}->init;
+
 	# Initialise the landscape so there is a world
 	$self->{landscape}->init;
 
+	# Enable GLUT support so we can have teapots
+	OpenGL::glutInit();
+
 	# Initialise the actors (probably nothing to do though)
 	foreach my $actor ( @{$self->{actors}} ) {
 		$actor->init;
@@ -220,6 +233,9 @@ sub display {
 	# NOTE: For now just translate back so we can see the render.
 	$self->{camera}->display;
 
+	# Draw the skybox
+	$self->{skybox}->display;
+
 	# Draw the landscape
 	$self->{landscape}->display;
 
